#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Sat Feb 13 15:55:39 2021

@author: anton
"""
from SLiCAP import *
fileName = 'ABCD-test'

#makeNetlist(fileName + '.asc', 'ABCD-test')

prj = initProject(fileName)

i1 = instruction()
i1.setCircuit(fileName + '.cir')

i1.setSimType('symbolic')
i1.setGainType('gain')
i1.setDataType('laplace')

i1.setSource('V1')

R_ell = sp.Symbol('R_ell')

# determination of Vi
# Vi is the transfer from V1 to the voltage V_i at node i
i1.setDetector('V_i')
result = i1.execute()
V_i = result.laplace

# determination of Ii
# Ii is the transfer from V1 to the current through V1
i1.setDetector('I_V1')
result = i1.execute()
I_i = -result.laplace

# determination of Vo
# Vo is the transfer from V1 to the voltage V_o at node o
i1.setDetector('V_o')
result = i1.execute()
V_o = result.laplace

# determination of Io
# Io is the transfer from V1 to the current through R2
i1.setDetector('I_R2')
result = i1.execute()
I_o = result.laplace

# Calculate the T1 parameters
A = sp.simplify(sp.limit(V_i/V_o, R_ell, 'oo'))
B = sp.simplify(sp.limit(V_i/I_o, R_ell, 0))
C = sp.simplify(sp.limit(I_i/V_o, R_ell, 'oo'))
D = sp.simplify(sp.limit(I_i/I_o, R_ell, 0))

htmlPage('Determination of T1 matrix parameters')
head2html('Test circuit')
img2html('ABCD-test.svg', 400)
head2html('T1 matrix of the device under test')
text2html('The T1 matrix of the device under test is found as:')
T1 = sp.Matrix([[A,B], [C,D]])
eqn2html('T_1', T1)
ViIi = sp.Matrix([[sp.Symbol('V_i')], [sp.Symbol('I_i')]])
VoIo = sp.Matrix([[sp.Symbol('V_o')], [sp.Symbol('I_o')]])
text2html('The matrix equation for the two-port (DUT) is found as:')
eqn2html(ViIi, T1*VoIo)